﻿using DataManagers;
using DbConnectionLibrairie;
using DTOs;
using ManagerInterfaces;
using Microsoft.AspNetCore.Mvc;
using ServiceManagers;
using Microsoft.Extensions.Logging;
using OrderCriterias;
using Microsoft.AspNetCore.Http.HttpResults;

namespace WebApi.Controllers
{
    [ApiController]
    [Route("api/[controller]")]
    public class AdministratorController
    {
        private IAdministratorManager<AdministratorDto> mgr;

        private readonly Logger<AdministratorController> logger;

        public AdministratorController(MyDbContext dbContext, Logger<AdministratorController> logger)
        {
            mgr = new AdministratorServiceManager(dbContext);
            this.logger = logger;
        }

        [HttpPost("add/administrator/")]
        public async Task<IActionResult> PostAdministrator([FromBody] AdministratorDto administrator)
        {
            int count = mgr.getNbElements();
            var tmp = await mgr.addAdmin(administrator);
            if (mgr.getNbElements() == count) // <=> not added
            {
                return StatusCode(208) ;
            }
            logger.LogInformation(message: $"administrator added : {administrator.ToString()}");
            return StatusCode(202);
        }

        [HttpGet("administrators")]
        public async Task<IActionResult> GetSomeAdministrators(int page, int count = 10, AdministratorOrderCriteria orderCriteria = AdministratorOrderCriteria.ById)
        {
            var tmp = await mgr.getAdministrators(page, count, orderCriteria);
            if (tmp.administrators == null)
            {
                return BadRequest(tmp);
            }
            else return Ok(tmp);
        }

        [HttpDelete()]
        public async Task<IActionResult> DeleteAdministrator(int id)
        {
            if (id < 0)
            {
                return BadRequest();
            }
            var tmp = await mgr.removeAdmin(id);
            if (tmp == null) return StatusCode(403);
            logger.LogInformation(message: $"administrator removed : ${tmp}");
            return Ok(tmp);
        }
    }
}
